@@ -662,8 +662,8 @@ help_and_report <- function(modal_title, fun_name, help_file,
        </div>
      </div>
      <i title='Help' class='fa fa-question alignleft' data-toggle='modal' data-target='#%s_help'></i>
-     <i title='Report results & Screenshot' class='fa fa-camera action-button shiny-bound-input aligncenter' href='#%s_screenshot' id='%s_screenshot' onclick='generate_screenshot();'></i>
-     <i title='Report results' class='fa fa-edit action-button shiny-bound-input alignright' href='#%s_report' id='%s_report'></i>
+     <i title='Report results & Screenshot' class='fa fa-camera action-button aligncenter' href='#%s_screenshot' id='%s_screenshot' onclick='generate_screenshot();'></i>
+     <i title='Report results' class='fa fa-edit action-button alignright' href='#%s_report' id='%s_report'></i>
      <div style='clear: both;'></div>",
     fun_name, fun_name, fun_name, modal_title, help_file, author, year, lic, lic, fun_name, fun_name, fun_name, fun_name, fun_name
   ) %>%
@@ -675,11 +675,7 @@ help_and_report <- function(modal_title, fun_name, help_file,
 ## function to render .md files to html
 inclMD <- function(path) {
   paste(readLines(path, warn = FALSE), collapse = "\n") %>%
-    # markdown::markdownToHTML(
-    #   text = ., fragment.only = TRUE, options = "",
-    #   stylesheet = ""
-    # markdown::markdownToHTML(
-    markdown::mark_html(text = ., template = FALSE, options = "", meta = list(css = ""))
+    markdown::mark_html(text = ., template = FALSE, meta = list(css = ""), output = FALSE)
 }
 
 ## function to render .Rmd files to html
@@ -687,7 +683,7 @@ inclRmd <- function(path) {
   paste(readLines(path, warn = FALSE), collapse = "\n") %>%
     knitr::knit2html(
       text = ., template = FALSE, quiet = TRUE,
-      envir = r_data, options = "", meta = list(css = "")
+      envir = r_data, meta = list(css = ""), output = FALSE
     ) %>%
     HTML() %>%
     withMathJax()
